# PEMA: Peak matching for clustering and classification
[![Test package](https://github.com/XENONnT/pema/actions/workflows/pytest.yml/badge.svg?branch=master)](https://github.com/XENONnT/pema/actions/workflows/pytest.yml)
[![CodeFactor](https://www.codefactor.io/repository/github/xenonnt/pema/badge)](https://www.codefactor.io/repository/github/xenonnt/pema)
[![Coverage Status](https://coveralls.io/repos/github/XENONnT/pema/badge.svg?branch=master)](https://coveralls.io/github/XENONnT/pema?branch=master)
[![Documentation Status](https://readthedocs.org/projects/pema/badge/?version=latest)](https://pema.readthedocs.io/en/latest/?badge=latest)

[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.5594916.svg)](https://doi.org/10.5281/zenodo.5594916)
[![PyPI version shields.io](https://img.shields.io/pypi/v/pema.svg)](https://pypi.python.org/pypi/pema/)
[![Python Versions](https://img.shields.io/pypi/pyversions/pema.svg)](https://pypi.python.org/pypi/pema)
[![PyPI downloads](https://img.shields.io/pypi/dm/pema.svg)](https://pypistats.org/packages/pema)

## PeakMatching
Peak clustering and classification validation using the WFsim


# Installation
To install `pema`, one can easily get the latest version via Pipy. For increased usability one needs some XENONnT credentials, see [this page](https://straxen.readthedocs.io/en/latest/setup.html).
```bash
pip install pema
```


## Test installation
```bash
python -c "import pema ; print(pema.__version__) ; print('great succes')
```
